pub fn design_from_spec(spec: &str) -> Result<(Intersection, PhasePlan), String>Expand description
Parse an English spec into an Intersection, then design its minimal plan.
pub fn design_from_spec(spec: &str) -> Result<(Intersection, PhasePlan), String>Parse an English spec into an Intersection, then design its minimal plan.